@@ -49,6 +49,7 @@
 #include "magick/geometry.h"
 #include "magick/image.h"
 #include "magick/list.h"
+#include "magick/log.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
@@ -136,17 +137,25 @@ static MagickBooleanType
 static MagickBooleanType DecodeImage(Image *image,
   const MagickBooleanType compression,unsigned char *pixels)
 {
+#if !defined(__WINDOWS__) || defined(__MINGW32__)
+#define BI_RLE8  1
+#endif
+
   int
     count;
 
   long
     y;
 
+  MagickBooleanType
+    status;
+
   register long
     i,
     x;
 
   register unsigned char
+    *p,
     *q;
 
   unsigned char
@@ -157,30 +166,37 @@ static MagickBooleanType DecodeImage(Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   assert(pixels != (unsigned char *) NULL);
-  (void) ResetMagickMemory(pixels,0,image->columns*image->rows);
+  (void) ResetMagickMemory(pixels,0,(size_t) image->columns*image->rows);
   byte=0;
   x=0;
-  q=pixels;
+  p=pixels;
+  q=pixels+(size_t) image->columns*image->rows;
   for (y=0; y < (long) image->rows; )
   {
+    if ((p < pixels) || (p >= q))
+      break;
     count=ReadBlobByte(image);
     if (count == EOF)
       break;
     if (count != 0)
       {
+        count=Min(count,q-p);
         /*
           Encoded mode.
         */
         byte=(unsigned char) ReadBlobByte(image);
-        for (i=0; i < (long) count; i++)
-        {
-          if (compression == 1)
-            *q++=byte;
-          else
-            *q++=(unsigned char)
-              ((i & 0x01) ? (byte & 0x0f) : ((byte >> 4) & 0x0f));
-          x++;
-        }
+        if (compression == BI_RLE8)
+          {
+            for (i=count; i != 0; i--)
+              *p++=(unsigned char) byte;
+          }
+        else
+          {
+            for (i=0; i < count; i++)
+              *p++=(unsigned char)
+                ((i & 0x01) != 0 ? (byte & 0x0f) : ((byte >> 4) & 0x0f));
+          }
+        x+=count;
       }
     else
       {
@@ -199,7 +215,7 @@ static MagickBooleanType DecodeImage(Image *image,
             */
             x=0;
             y++;
-            q=pixels+y*image->columns;
+            p=pixels+y*image->columns;
             break;
           }
           case 0x02:
@@ -209,7 +225,7 @@ static MagickBooleanType DecodeImage(Image *image,
             */
             x+=ReadBlobByte(image);
             y+=ReadBlobByte(image);
-            q=pixels+y*image->columns+x;
+            p=pixels+y*image->columns+x;
             break;
           }
           default:
@@ -217,25 +233,25 @@ static MagickBooleanType DecodeImage(Image *image,
             /*
               Absolute mode.
             */
-            for (i=0; i < (long) count; i++)
-            {
-              if (compression == 1)
-                *q++=(unsigned char) ReadBlobByte(image);
-              else
-                {
-                  if ((i & 0x01) == 0)
-                    byte=(unsigned char) ReadBlobByte(image);
-                  *q++=(unsigned char)
-                    ((i & 0x01) ? (byte & 0x0f) : ((byte >> 4) & 0x0f));
-                }
-              x++;
-            }
+            count=Min(count,q-p);
+            if (compression == BI_RLE8)
+              for (i=(long) count; i != 0; --i)
+                *p++=(unsigned char) ReadBlobByte(image);
+            else
+              for (i=0; i < count; i++)
+              {
+                if ((i & 0x01) == 0)
+                  byte=(unsigned char) ReadBlobByte(image);
+                *p++=(unsigned char)
+                  ((i & 0x01) != 0 ? (byte & 0x0f) : ((byte >> 4) & 0x0f));
+              }
+            x+=count;
             /*
               Read pad byte.
             */
-            if (compression == 1)
+            if (compression == BI_RLE8)
               {
-                if (count & 0x01)
+                if ((count & 0x01) != 0)
                   (void) ReadBlobByte(image);
               }
             else
@@ -245,9 +261,12 @@ static MagickBooleanType DecodeImage(Image *image,
           }
         }
       }
-    if (QuantumTick(y,image->rows) != 0)
-      if (MagickMonitor(LoadImageTag,y,image->rows,&image->exception) == MagickFalse)
-        break;
+    if (QuantumTick(y,image->rows) != MagickFalse)
+      {
+        status=MagickMonitor(LoadImageTag,y,image->rows,&image->exception);
+        if (status == MagickFalse)
+          break;
+      }
   }
   (void) ReadBlobByte(image);  /* end of line */
   (void) ReadBlobByte(image);
@@ -275,9 +294,6 @@ static MagickBooleanType DecodeImage(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method EncodeImage returns the number of bytes in the
-%      runlength encoded compress_pixels array.
-%
 %    o image:  The image.
 %
 %    o bytes_per_line: The number of bytes in a scanline of compressed pixels
@@ -337,7 +353,7 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
     */
     *q++=0x00;
     *q++=0x00;
-    if (QuantumTick(y,image->rows) != 0)
+    if (QuantumTick(y,image->rows) != MagickFalse)
       if (MagickMonitor(SaveImageTag,y,image->rows,&image->exception) == MagickFalse)
         break;
   }
@@ -369,8 +385,6 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method IsDIB() returns MagickTrue if the image format type is DIB.
-%
 %    o magick: This string is generally the first few bytes of an image file
 %      or blob.
 %
@@ -408,10 +422,6 @@ static MagickBooleanType IsDIB(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadDIBImage returns a pointer to the image after
-%      reading.  A null image is returned if there is a memory shortage or
-%      if the image cannot be read.
-%
 %    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -479,7 +489,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine if this is a DIB file.
   */
-  (void) ResetMagickMemory(&dib_info,0,sizeof(DIBInfo));
+  (void) ResetMagickMemory(&dib_info,0,sizeof(dib_info));
   dib_info.size=ReadBlobLSBLong(image);
   if (dib_info.size!=40)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -503,7 +513,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       dib_info.green_mask=ReadBlobLSBShort(image);
       dib_info.blue_mask=ReadBlobLSBShort(image);
     }
-  image->matte=dib_info.bits_per_pixel == 32;
+  image->matte=dib_info.bits_per_pixel == 32 ? MagickTrue : MagickFalse;
   image->columns=dib_info.width;
   image->rows=AbsoluteValue(dib_info.height);
   image->depth=8;
@@ -577,7 +587,8 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /*
         Convert run-length encoded raster pixels.
       */
-      status=DecodeImage(image,dib_info.compression,pixels);
+      status=DecodeImage(image,dib_info.compression ? MagickTrue : MagickFalse,
+        pixels);
       if (status == MagickFalse)
         ThrowReaderException(CorruptImageError,"UnableToRunlengthDecodeImage");
     }
@@ -627,7 +638,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(LoadImageTag,image->rows-y-1,image->rows,
                 exception);
@@ -669,7 +680,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(LoadImageTag,image->rows-y-1,image->rows,
                 exception);
@@ -704,7 +715,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(LoadImageTag,image->rows-y-1,image->rows,
                 exception);
@@ -752,7 +763,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(LoadImageTag,image->rows-y-1,image->rows,
                 exception);
@@ -786,7 +797,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (SyncImagePixels(image) == MagickFalse)
           break;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(LoadImageTag,image->rows-y-1,image->rows,
                 exception);
@@ -908,10 +919,6 @@ ModuleExport void UnregisterDIBImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o status: Method WriteDIBImage returns True if the image is written.
-%      False is returned is there is a memory shortage or if the image file
-%      fails to write.
-%
 %    o image_info: The image info.
 %
 %    o image:  The image.
@@ -992,16 +999,22 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
   dib_info.image_size=bytes_per_line*image->rows;
   dib_info.x_pixels=75*39;
   dib_info.y_pixels=75*39;
-  if (image->units == PixelsPerInchResolution)
+  switch (image->units)
+  {
+    case UndefinedResolution:
+    case PixelsPerInchResolution:
     {
       dib_info.x_pixels=(unsigned long) (100.0*image->x_resolution/2.54);
       dib_info.y_pixels=(unsigned long) (100.0*image->y_resolution/2.54);
+      break;
     }
-  if (image->units == PixelsPerCentimeterResolution)
+    case PixelsPerCentimeterResolution:
     {
       dib_info.x_pixels=(unsigned long) (100.0*image->x_resolution);
       dib_info.y_pixels=(unsigned long) (100.0*image->y_resolution);
+      break;
     }
+  }
   dib_info.colors_important=dib_info.number_colors;
   /*
     Convert MIFF to DIB raster pixels.
@@ -1051,7 +1064,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
        for (x=(long) (image->columns+7)/8; x < (long) bytes_per_line; x++)
          *q++=0x00;
        if (image->previous == (Image *) NULL)
-         if (QuantumTick(y,image->rows) != 0)
+         if (QuantumTick(y,image->rows) != MagickFalse)
            {
              status=MagickMonitor(SaveImageTag,y,image->rows,&image->exception);
              if (status == MagickFalse)
@@ -1077,7 +1090,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         for ( ; x < (long) bytes_per_line; x++)
           *q++=0x00;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(SaveImageTag,y,image->rows,
                 &image->exception);
@@ -1112,7 +1125,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
           for (x=3*image->columns; x < (long) bytes_per_line; x++)
             *q++=0x00;
         if (image->previous == (Image *) NULL)
-          if (QuantumTick(y,image->rows) != 0)
+          if (QuantumTick(y,image->rows) != MagickFalse)
             {
               status=MagickMonitor(SaveImageTag,y,image->rows,
                 &image->exception);
