@@ -80,8 +80,6 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method IsFITS() returns MagickTrue if the image format type is FITS.
-%
 %    o magick: This string is generally the first few bytes of an image file
 %      or blob.
 %
@@ -353,10 +351,10 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     */
     image->columns=(unsigned long) fits_info.columns;
     image->rows=(unsigned long) fits_info.rows;
-    image->depth=fits_info.bits_per_pixel <= 8 ? 8UL : QuantumDepth;
+    image->depth=fits_info.bits_per_pixel <= 8 ? 8UL : Min(QuantumDepth,16);
     image->storage_class=PseudoClass;
     image->scene=(unsigned long) scene;
-    if (AllocateImageColormap(image,1 << image->depth) == MagickFalse)
+    if (AllocateImageColormap(image,1UL << image->depth) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"UnableToAllocateColormap");
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -381,7 +379,10 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     count=ReadBlob(image,packet_size*image->columns*image->rows,fits_pixels);
     if (count == 0)
       ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
-    if ((fits_info.min_data == 0.0) || (fits_info.max_data == 0.0))
+    if ((fits_info.bits_per_pixel > 0) &&
+        (fits_info.min_data == 0.0) && (fits_info.max_data == 0.0))
+      fits_info.max_data=(1UL << fits_info.bits_per_pixel)-1;
+    else
       {
         /*
           Determine minimum and maximum intensity.
@@ -484,7 +485,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     scale=1.0;
     if ((fits_info.bits_per_pixel < 0) || ((fits_info.max_data-
         fits_info.min_data) > (double) ((1UL << image->depth)-1)))
-      scale=(double) ((1 << image->depth)-1)/
+      scale=(double) ((1UL << image->depth)-1)/
         (fits_info.max_data-fits_info.min_data);
     p=fits_pixels;
     for (y=(long) image->rows-1; y >= 0; y--)
@@ -547,7 +548,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       }
       if (SyncImagePixels(image) == MagickFalse)
         break;
-      if (QuantumTick(y,image->rows) != 0)
+      if (QuantumTick(y,image->rows) != MagickFalse)
         if (MagickMonitor(LoadImageTag,y,image->rows,exception) == MagickFalse)
           break;
     }
@@ -668,10 +669,6 @@ ModuleExport void UnregisterFITSImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o status: Method WriteFITSImage returns True if the image is written.
-%      False is returned is there is a memory shortage or if the image file
-%      fails to write.
-%
 %    o image_info: The image info.
 %
 %    o image:  The image.
@@ -690,6 +687,9 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
   MagickBooleanType
     status;
 
+  MagickSizeType
+    length;
+
   register const PixelPacket
     *p;
 
@@ -719,7 +719,7 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
     Allocate image memory.
   */
   packet_size=(size_t) (image->depth > 8 ? 2 : 1);
-  fits_info=(char *) AcquireMagickMemory(2880);
+  fits_info=(char *) AcquireMagickMemory(2880*sizeof(*fits_info));
   pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
   if ((fits_info == (char *) NULL) || (pixels == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -751,7 +751,6 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
   (void) strcpy(buffer,"END");
   (void) strncpy(fits_info+640,buffer,strlen(buffer));
   (void) WriteBlob(image,2880,(unsigned char *) fits_info);
-  fits_info=(char *) RelinquishMagickMemory(fits_info);
   /*
     Convert image to fits scale PseudoColor class.
   */
@@ -770,6 +769,10 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
           break;
       }
   }
+  (void) ResetMagickMemory(fits_info,0,2880*sizeof(*fits_info));
+  length=packet_size*image->columns*image->rows;
+  (void) WriteBlob(image,2880-(length % 2880),(unsigned char *) fits_info);
+  fits_info=(char *) RelinquishMagickMemory(fits_info);
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   CloseBlob(image);
   return(MagickTrue);
