@@ -102,8 +102,6 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method IsJP2() returns MagickTrue if the image format type is JP2.
-%
 %    o magick: This string is generally the first few bytes of an image file
 %      or blob.
 %
@@ -181,10 +179,6 @@ static MagickBooleanType IsJPC(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadJP2Image returns a pointer to the image after
-%      reading.  A null image is returned if there is a memory shortage or
-%      if the image cannot be read.
-%
 %    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -249,12 +243,12 @@ static jas_stream_t *JP2StreamManager(Image *image)
   StreamManager
     *source;
 
-  stream=(jas_stream_t *) malloc(sizeof(jas_stream_t));
+  stream=(jas_stream_t *) AcquireMagickMemory(sizeof(*stream));
   if (stream == (jas_stream_t *) NULL)
     return((jas_stream_t *) NULL);
-  (void) ResetMagickMemory(stream,0,sizeof(jas_stream_t));
+  (void) ResetMagickMemory(stream,0,sizeof(*stream));
   stream->rwlimit_=(-1);
-  stream->obj_=(jas_stream_obj_t *) malloc(sizeof(StreamManager));
+  stream->obj_=(jas_stream_obj_t *) AcquireMagickMemory(sizeof(StreamManager));
   if (stream->obj_ == (jas_stream_obj_t *) NULL)
     return((jas_stream_t *) NULL);
   (void) ResetMagickMemory(stream->obj_,0,sizeof(StreamManager));
@@ -522,7 +516,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
     if (SyncImagePixels(image) == MagickFalse)
       break;
     if (image->previous == (Image *) NULL)
-      if (QuantumTick(y,image->rows) != 0)
+      if (QuantumTick(y,image->rows) != MagickFalse)
         if (MagickMonitor(LoadImagesTag,y,image->rows,exception) == MagickFalse)
           break;
   }
@@ -646,10 +640,6 @@ ModuleExport void UnregisterJP2Image(void)
 %
 %  A description of each parameter follows.
 %
-%    o status: Method WriteJP2Image returns True if the image is written.
-%      False is returned is there is a memory shortage or if the image file
-%      fails to write.
-%
 %    o image_info: The image info.
 %
 %    o image:  The image.
@@ -732,8 +722,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
     ThrowWriterException(DelegateError,"UnableToCreateImage");
   for (i=0; i < (long) number_components; i++)
   {
-    (void) ResetMagickMemory((void *) &component_info,0,
-      sizeof(jas_image_cmptparm_t));
+    (void) ResetMagickMemory((void *) &component_info,0,sizeof(component_info));
     component_info.tlx=0;
     component_info.tly=0;
     component_info.hstep=1;
@@ -804,7 +793,8 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
             jas_matrix_setv(pixels[1],x,ScaleQuantumToChar(p->green));
             jas_matrix_setv(pixels[2],x,ScaleQuantumToChar(p->blue));
             if (number_components > 3)
-              jas_matrix_setv(pixels[3],x,ScaleQuantumToChar(p->opacity));
+              jas_matrix_setv(pixels[3],x,
+                ScaleQuantumToChar(MaxRGB-p->opacity));
           }
         p++;
       }
@@ -829,7 +819,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
       (void) jas_image_writecmpt(jp2_image,(short) i,0,(unsigned int) y,
         (unsigned int) image->columns,1,pixels[i]);
     if (image->previous == (Image *) NULL)
-      if (QuantumTick(y,image->rows) != 0)
+      if (QuantumTick(y,image->rows) != MagickFalse)
         {
           status=MagickMonitor(SaveImageTag,y,image->rows,&image->exception);
           if (status == MagickFalse)
@@ -891,7 +881,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
       header_size=550.0;
       header_size+=(number_components-1)*142;
       number_pixels=(double) image->rows*image->columns*number_components*
-        (GetImageQuantumDepth(image)/8);
+        (GetImageQuantumDepth(image,MagickTrue)/8);
       target_size=(number_pixels*rate)+header_size;
       rate=target_size/number_pixels;
       FormatMagickString(option,MaxTextExtent,"rate=%g",rate);
