@@ -265,8 +265,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
           */
           length=MaxTextExtent;
           comment=AcquireString((char *) NULL);
-          p=comment;
-          for ( ; comment != (char *) NULL; p++)
+          for (p=comment; comment != (char *) NULL; p++)
           {
             c=ReadBlobByte(image);
             if ((c == EOF) || (c == (int) '}'))
@@ -275,7 +274,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               {
                 *p='\0';
                 length<<=1;
-                comment=(char *) ResizeMagickMemory(comment,length);
+                comment=(char *) ResizeMagickMemory(comment,
+                  (length+MaxTextExtent)*sizeof(*comment));
                 if (comment == (char *) NULL)
                   break;
                 p=comment+strlen(comment);
@@ -313,7 +313,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 {
                   *p='\0';
                   length<<=1;
-                  options=(char *) ResizeMagickMemory(options,length);
+                  options=(char *) ResizeMagickMemory(options,
+                    (length+MaxTextExtent)*sizeof(*options));
                   if (options == (char *) NULL)
                     break;
                   p=options+strlen(options);
@@ -655,20 +656,20 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Image directory.
         */
+        length=MaxTextExtent;
         image->directory=AcquireString((char *) NULL);
-        if (image->directory == (char *) NULL)
-          ThrowReaderException(CorruptImageError,"UnableToReadImageData");
         p=image->directory;
         do
         {
           *p='\0';
-          if (((strlen(image->directory)+1) % MaxTextExtent) == 0)
+          if ((strlen(image->directory)+MaxTextExtent) >= length)
             {
               /*
                 Allocate more memory for the image directory.
               */
+              length<<=1;
               image->directory=(char *) ResizeMagickMemory(image->directory,
-                (strlen(image->directory)+MaxTextExtent+1));
+                (length+MaxTextExtent)*sizeof(*image->directory));
               if (image->directory == (char *) NULL)
                 ThrowReaderException(CorruptImageError,"UnableToReadImageData");
               p=image->directory+strlen(image->directory);
@@ -696,7 +697,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         DestroyLinkedList(profiles,RelinquishMagickMemory);
       }
-    depth=GetImageQuantumDepth(image);
+    depth=GetImageQuantumDepth(image,MagickFalse);
     if (image->storage_class == PseudoClass)
       {
         /*
@@ -728,7 +729,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
             switch (depth)
             {
               default:
-                ThrowWriterException(CorruptImageError,
+                ThrowReaderException(CorruptImageError,
                   "ImageDepthNotSupported");
               case 8:
               {
@@ -1178,7 +1179,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
         /*
           Allocate colormap.
         */
-        depth=GetImageQuantumDepth(image);
+        depth=GetImageQuantumDepth(image,MagickTrue);
         packet_size=(size_t) (depth > 8 ? 6 : 3);
         colormap=(unsigned char *)
           AcquireMagickMemory(packet_size*image->colors);
