@@ -889,10 +889,6 @@ static const PatternInfo
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadPATTERNImage returns a pointer to the image after
-%      reading.  A null image is returned if there is a memory shortage or
-%      if the image cannot be read.
-%
 %    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
