@@ -100,12 +100,11 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method RegisterPS3Image adds attributes for the PS3 image format to
-%  the list of supported formats.  The attributes include the image format
-%  tag, a method to read and/or write the format, whether the format
-%  supports the saving of more than one frame to the same file or blob,
-%  whether the format supports native in-memory I/O, and a brief
-%  description of the format.
+%  RegisterPS3Image() adds attributes for the PS3 image format to the list of
+%  supported formats.  The attributes include the image format tag, a method to
+%  read and/or write the format, whether the format supports the saving of more
+%  than one frame to the same file or blob, whether the format supports native
+%  in-memory I/O, and a brief description of the format.
 %
 %  The format of the RegisterPS3Image method is:
 %
@@ -140,8 +139,8 @@ ModuleExport void RegisterPS3Image(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method UnregisterPS3Image removes format registrations made by the
-%  PS3 module from the list of supported formats.
+%  UnregisterPS3Image() removes format registrations made by the PS3 module
+%  from the list of supported formats.
 %
 %  The format of the UnregisterPS3Image method is:
 %
@@ -165,10 +164,10 @@ ModuleExport void UnregisterPS3Image(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method WritePS3Image translates an image to encapsulated Postscript
-%  Level III for printing.  If the supplied geometry is null, the image is
-%  centered on the Postscript page.  Otherwise, the image is positioned as
-%  specified by the geometry.
+%  WritePS3Image() translates an image to encapsulated Postscript Level III
+%  for printing.  If the supplied geometry is null, the image is centered on
+%  the Postscript page.  Otherwise, the image is positioned as specified by the
+%  geometry.
 %
 %  The format of the WritePS3Image method is:
 %
@@ -176,13 +175,9 @@ ModuleExport void UnregisterPS3Image(void)
 %
 %  A description of each parameter follows:
 %
-%    o status: Method WritePS3Image returns True if the image is printed.
-%      False is returned if the image file cannot be opened for printing.
-%
 %    o image_info: Specifies a pointer to a ImageInfo structure.
 %
-%    o image: The address of a structure of type Image;  returned from
-%      ReadImage.
+%    o image: The image.
 %
 %
 */
@@ -243,7 +238,7 @@ static MagickBooleanType SerializeImage(const ImageInfo *image_info,
         p++;
       }
     if (image->previous == (Image *) NULL)
-      if (QuantumTick(y,image->rows) != 0)
+      if (QuantumTick(y,image->rows) != MagickFalse)
         {
           status=MagickMonitor(SaveImageTag,y,image->rows,&image->exception);
           if (status == MagickFalse)
@@ -324,7 +319,7 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
         }
       }
     if (image->previous == (Image *) NULL)
-      if (QuantumTick(y,image->rows) != 0)
+      if (QuantumTick(y,image->rows) != MagickFalse)
         {
           status=MagickMonitor(SaveImageTag,y,image->rows,
             &image->exception);
@@ -377,7 +372,7 @@ static MagickBooleanType SerializeImageIndexes(const ImageInfo *image_info,
     for (x=0; x < (long) image->columns; x++)
       *q++=(unsigned char) indexes[x];
     if (image->previous == (Image *) NULL)
-      if (QuantumTick(y,image->rows) != 0)
+      if (QuantumTick(y,image->rows) != MagickFalse)
         {
           status=MagickMonitor(SaveImageTag,y,image->rows,&image->exception);
           if (status == MagickFalse)
@@ -446,6 +441,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,Image *im
         image->columns,image->rows);
     }
     case FaxCompression:
+    case Group4Compression:
     default:
     {
       (void) FormatMagickString(buffer,MaxTextExtent,
@@ -512,6 +508,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,Image *im
       break;
     }
     case FaxCompression:
+    case Group4Compression:
     default:
     {
       if (LocaleCompare(CCITTParam,"0") == 0)
@@ -944,7 +941,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         (void) WriteBlobString(image,buffer);
         timer=time((time_t *) NULL);
         (void) localtime(&timer);
-        (void) strncpy(date,ctime(&timer),MaxTextExtent-1);
+        (void) CopyMagickString(date,ctime(&timer),MaxTextExtent);
         date[strlen(date)-1]='\0';
         (void) FormatMagickString(buffer,MaxTextExtent,
           "%%%%CreationDate: %s\n",date);
@@ -953,7 +950,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         bounds.y1=(double) geometry.y;
         bounds.x2=(double) geometry.x+x_scale;
         bounds.y2=(double) geometry.y+y_scale+text_size;
-        if ((image_info->adjoin != MagickFalse) && (image->next != (Image *) NULL))
+        if ((image_info->adjoin != MagickFalse) &&
+            (image->next != (Image *) NULL))
           {
             (void) WriteBlobString(image,"%%BoundingBox: (atend)\n");
             (void) WriteBlobString(image,"%%HiResBoundingBox: (atend)\n");
@@ -1156,7 +1154,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         (void) WriteBlobString(image,"true\n");
       else
         (void) WriteBlobString(image,"false\n");
-    if (compression == FaxCompression)
+    if ((compression == FaxCompression) || (compression == Group4Compression))
       (void) SetImageType(image,BilevelType);
     /*
       Showpage for non-EPS.
@@ -1208,6 +1206,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
             break;
           }
           case FaxCompression:
+          case Group4Compression:
           {
             (void) WriteBlobString(image,PS3_FaxCompression"\n");
             break;
@@ -1249,7 +1248,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         if (compression == JPEGCompression)
           status=JPEGEncodeImage(image_info,image);
         else
-          if (compression == FaxCompression)
+          if ((compression == FaxCompression) ||
+              (compression == Group4Compression))
            {
              if (LocaleCompare(CCITTParam,"0") == 0)
                status=HuffmanEncodeImage(image_info,image);
