@@ -64,8 +64,8 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsWPG()() returns MagickTrue if the image format type, identified by the magick
-%  string, is WPG.
+%  IsWPG()() returns MagickTrue if the image format type, identified by the
+%  magick string, is WPG.
 %
 %  The format of the IsWPG method is:
 %
@@ -73,8 +73,6 @@
 %
 %  A description of each parameter follows:
 %
-%    o status:  Method IsWPG() returns MagickTrue if the image format type is WPG.
-%
 %    o magick: This string is generally the first few bytes of an image file
 %      or blob.
 %
@@ -287,19 +285,19 @@ static void InsertRow(unsigned char *p,long y,Image *image, int bpp)
 }
 static int UnpackWPGRaster(Image *image,int bpp)
 {
-  int
-    x,
-    y,
-    i;
+  long
+    ldblk,
+    y;
+
+  register long
+    i,
+    x;
 
   unsigned char
     bbuf,
     *BImgBuff,
     RunCount;
 
-  long
-    ldblk;
-
   x=0;
   y=0;
 
@@ -307,8 +305,8 @@ static int UnpackWPGRaster(Image *image,int bpp)
   BImgBuff=(unsigned char *) AcquireMagickMemory(ldblk);
   if(BImgBuff==NULL) return(-2);
 
-  while(y<(long) image->rows)
-    {
+  while (y < (long) image->rows)
+  {
       bbuf=ReadBlobByte(image);
 
       /*
@@ -373,21 +371,20 @@ static int UnpackWPG2Raster(Image *image,int bpp)
   char
     SampleSize=1;
 
+  register long
+    i,
+    x;
+
+  long
+    ldblk,
+    y;
+
   unsigned char
     bbuf,
     *BImgBuff,
     RunCount,
     SampleBuffer[8];
 
-  int
-    x,
-    y,
-    i;
-
-  long
-    ldblk;
-
-
   x=0;
   y=0;
   ldblk=(long) ((bpp*image->columns+7)/8);
@@ -403,18 +400,20 @@ static int UnpackWPG2Raster(Image *image,int bpp)
         {
         case 0x7D:
           SampleSize=ReadBlobByte(image);  /* DSZ */
-          if(SampleSize>8) return(-2);
-          if(SampleSize<1) return(-2);
+          if (SampleSize > 8)
+            return(-2);
+          if (SampleSize < 1)
+            return(-2);
           break;
         case 0x7E:
           fprintf(stderr,"\nUnsupported WPG token XOR, please report!");
           break;
         case 0x7F:
           RunCount=ReadBlobByte(image);   /* BLK */
-          for(i=0;i<(int) SampleSize*((int)RunCount+1);i++)
-            {
-              InsertByte(0);
-            }
+          for(i=0; i < (long) SampleSize*((long)RunCount+1); i++)
+          {
+            InsertByte(0);
+          }
           break;
         case 0xFD:
           RunCount=ReadBlobByte(image);   /* EXT */
@@ -427,7 +426,7 @@ static int UnpackWPG2Raster(Image *image,int bpp)
           if(x!=0)
             {
               fprintf(stderr,
-                "\nUnsupported WPG2 unaligned token RST x=%d, please report!\n"
+                "\nUnsupported WPG2 unaligned token RST x=%ld, please report!\n"
                   ,x);
               return(-3);
             }
@@ -436,8 +435,8 @@ static int UnpackWPG2Raster(Image *image,int bpp)
            for(i=0;i<=RunCount;i++)
               {
               x=0;
-              InsertRow(BImgBuff,(long) (y< (long) image->rows?y:image->rows-1),
-                  image,bpp);
+              InsertRow(BImgBuff,(long) ( y< (long) image->rows ? y :
+                image->rows-1),image,bpp);
               y++;
               if(y<2) continue;
               if(y> (long) image->rows) return(-4);
@@ -478,56 +477,56 @@ static int UnpackWPG2Raster(Image *image,int bpp)
 unsigned LoadWPG2Flags(Image *image,char Precision,float *Angle)
 {
 const unsigned char TPR=1,TRN=2,SKW=4,SCL=8,ROT=0x10,OID=0x20,LCK=0x80;
-unsigned long  x;
+long  x;
 unsigned DenX;
 unsigned Flags;
-float CTM[3][3];        //current transform matrix (currently ignored:(((
+float CTM[3][3];        /* current transform matrix (currently ignored) */
                                                                                 
- ResetMagickMemory(CTM,0,sizeof(CTM));     //CTM.erase();CTM.resize(3,3);
+ ResetMagickMemory(CTM,0,sizeof(CTM));     /* CTM.erase();CTM.resize(3,3) */
  CTM[0][0]=1;
  CTM[1][1]=1;
  CTM[2][2]=1;
                                                                                 
  Flags=ReadBlobLSBShort(image);
- if(Flags & LCK) x=ReadBlobLSBLong(image);  //Edit lock
+ if(Flags & LCK) x=ReadBlobLSBLong(image);  /* Edit lock */
  if(Flags & OID)
   {
   if(Precision==0)
-    {x=ReadBlobLSBShort(image);}  //ObjectID
+    {x=ReadBlobLSBShort(image);}  /* ObjectID */
   else
-    {x=ReadBlobLSBLong(image);} //ObjectID (Double precision)
+    {x=ReadBlobLSBLong(image);}  /* ObjectID (Double precision). */
   }
  if(Flags & ROT)
   {
-  x=ReadBlobLSBLong(image); //Rot Angle
+  x=ReadBlobLSBLong(image);  /* Rot Angle. */
   if(Angle) *Angle=x/65536.0;
   }
  if(Flags & (ROT|SCL))
   {
-  x=ReadBlobLSBLong(image); //Sx*cos()
+  x=ReadBlobLSBLong(image); /* Sx*cos(). */
   CTM[0][0]=x;
-  x=ReadBlobLSBLong(image); //Sy*cos()
+  x=ReadBlobLSBLong(image); /* Sy*cos(). */
   CTM[1][1]=x;
   }
  if(Flags & (ROT|SKW))
   {
-  x=ReadBlobLSBLong(image);       //Kx*sin()
+  x=ReadBlobLSBLong(image);       /* Kx*sin(). */
   CTM[1][0]=x;
-  x=ReadBlobLSBLong(image);       //Ky*sin()
+  x=ReadBlobLSBLong(image);       /* Ky*sin(). */
   CTM[0][1]=x;
   }
  if(Flags & TRN)
   {
-  x=ReadBlobLSBLong(image); DenX=ReadBlobLSBLong(image); //Tx
-  CTM[0][2]=(float)x + ((x>=0)?1:-1)*(float)DenX/0x10000;
-  x=ReadBlobLSBLong(image); DenX=ReadBlobLSBLong(image); //Ty
-  CTM[1][2]=(float)x + ((x>=0)?1:-1)*(float)DenX/0x10000;
+  x=ReadBlobLSBLong(image); DenX=ReadBlobLSBLong(image);  /* Tx */
+  CTM[0][2]=(float)x + ((x >= 0)?1:-1)*(float)DenX/0x10000;
+  x=ReadBlobLSBLong(image); DenX=ReadBlobLSBLong(image);  /* Ty */
+  CTM[1][2]=(float)x + ((x >= 0)?1:-1)*(float)DenX/0x10000;
   }
  if(Flags & TPR)
   {
-  x=ReadBlobLSBLong(image); //Px
+  x=ReadBlobLSBLong(image);  /* Px. */
   CTM[2][0]=x;
-  x=ReadBlobLSBLong(image); //Py
+  x=ReadBlobLSBLong(image);  /* Py. */
   CTM[2][1]=x;
   }
  return(Flags);
@@ -582,13 +581,15 @@ static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
       (GetMagicName(magic_info) == (char *) NULL) ||
       (exception->severity != UndefinedException))
     goto FINISH_UNL;
-  (void) strncpy(clone_info->magick,GetMagicName(magic_info),MaxTextExtent-1);
+  (void) CopyMagickString(clone_info->magick,GetMagicName(magic_info),
+    MaxTextExtent);
   image2=ReadImage(clone_info,exception);
   if (image2 == (Image *) NULL)
     goto FINISH_UNL;
-  strncpy(image2->filename,image->filename,MaxTextExtent-1);
-  strncpy(image2->magick_filename,image->magick_filename,MaxTextExtent-1);
-  strncpy(image2->magick,image->magick,MaxTextExtent-1);
+  CopyMagickString(image2->filename,image->filename,MaxTextExtent);
+  CopyMagickString(image2->magick_filename,image->magick_filename,
+    MaxTextExtent);
+  CopyMagickString(image2->magick,image->magick,MaxTextExtent);
   image2->depth=image->depth;
   DestroyBlob(image2);
   image2->blob=ReferenceBlob(image->blob);
@@ -625,10 +626,6 @@ static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadWPGImage returns a pointer to the image after
-%      reading. A null image is returned if there is a memory shortage or if
-%      the image cannot be read.
-%
 %    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -986,13 +983,13 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                   }
                 }
               else {
-                if(bpp<24)
+                if (bpp < 24)
                   if( image->colors<(1UL<<bpp) && bpp!=24 )
                     image->colormap=(PixelPacket *) ResizeMagickMemory(
                       image->colormap,(1<<bpp)*sizeof(PixelPacket));
               }
 
-              if(bpp==1)
+              if (bpp == 1)
                 {
                   if(image->colormap[0].red==0 &&
                      image->colormap[0].green==0 &&
@@ -1120,7 +1117,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                     goto NoMemory;
                 }
               else {
-                if(bpp<24)
+                if (bpp < 24)
                   if( image->colors<(1UL<<bpp) && bpp!=24 )
                     image->colormap=(PixelPacket *) ResizeMagickMemory(
                       image->colormap,(1<<bpp)*sizeof(PixelPacket));
