@@ -516,8 +516,7 @@ static unsigned short *EncodeSJIS(const Image *image,const char *text,
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned short *) NULL);
   length=strlen(text)+MaxTextExtent;
-  encoding=(unsigned short *)
-    AcquireMagickMemory(length*sizeof(unsigned short));
+  encoding=(unsigned short *) AcquireMagickMemory(length*sizeof(*encoding));
   if (encoding == (unsigned short *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       image->filename);
@@ -586,7 +585,7 @@ static unsigned short *EncodeText(const Image *image,const char *text,
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned short *) NULL);
   encoding=(unsigned short *)
-    AcquireMagickMemory((strlen(text)+MaxTextExtent)*sizeof(unsigned short));
+    AcquireMagickMemory((strlen(text)+MaxTextExtent)*sizeof(*encoding));
   if (encoding == (unsigned short *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       image->filename);
@@ -704,8 +703,7 @@ static unsigned short *EncodeUnicode(const Image *image,const char *text,
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned short *) NULL);
   length=strlen(text)+MaxTextExtent;
-  unicode=(unsigned short *)
-    AcquireMagickMemory(length*sizeof(unsigned short));
+  unicode=(unsigned short *) AcquireMagickMemory(length*sizeof(*unicode));
   if (unicode == (unsigned short *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       image->filename);
@@ -789,7 +787,7 @@ MagickExport MagickBooleanType GetTypeMetrics(Image *image,
   assert(draw_info->signature == MagickSignature);
   annotate_info=CloneDrawInfo((ImageInfo *) NULL,draw_info);
   annotate_info->render=MagickFalse;
-  (void) ResetMagickMemory(metrics,0,sizeof(TypeMetric));
+  (void) ResetMagickMemory(metrics,0,sizeof(*metrics));
   offset.x=0.0;
   offset.y=0.0;
   status=RenderType(image,annotate_info,&offset,metrics);
@@ -818,9 +816,6 @@ MagickExport MagickBooleanType GetTypeMetrics(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o status: Method RenderType returns MagickTrue if the text is rendered on the
-%      image, otherwise MagickFalse.
-%
 %    o image: The image.
 %
 %    o draw_info: The draw info.
@@ -859,8 +854,8 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
     type_info=GetTypeInfoByFamily(draw_info->family,draw_info->style,
       draw_info->stretch,draw_info->weight,&image->exception);
   if (type_info == (const TypeInfo *) NULL)
-    (void) ThrowMagickException(&image->exception,GetMagickModule(),
-      TypeWarning,"UnableToReadFont",draw_info->font);
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),TypeWarning,
+      "UnableToReadFont",draw_info->font);
   if (type_info == (const TypeInfo *) NULL)
     type_info=GetTypeInfoByFamily("Arial",draw_info->style,draw_info->stretch,
       draw_info->weight,&image->exception);
@@ -898,9 +893,6 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
 %
 %  A description of each parameter follows:
 %
-%    o status: Method RenderFreetype returns MagickTrue if the text is rendered on the
-%      image, otherwise MagickFalse.
-%
 %    o image: The image.
 %
 %    o draw_info: The draw info.
@@ -1262,7 +1254,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     status=FT_Get_Glyph(face->glyph,&glyph.image);
     if (status != MagickFalse)
       continue;
-    FT_Outline_Get_BBox(&((FT_OutlineGlyph) glyph.image)->outline,&bounds);
+    (void) FT_Outline_Get_BBox(&((FT_OutlineGlyph) glyph.image)->outline,
+      &bounds);
     if ((i == 0) || (bounds.xMin < metrics->bounds.x1))
       metrics->bounds.x1=bounds.xMin;
     if ((i == 0) || (bounds.yMin < metrics->bounds.y1))
@@ -1309,7 +1302,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
             }
           q=GetImagePixels(image,(long) (point.x+0.5),(long) (point.y+y+0.5),
             bitmap->bitmap.width,1);
-          active=q != (PixelPacket *) NULL;
+          active=q != (PixelPacket *) NULL ? MagickTrue : MagickFalse;
           for (x=0; x < (long) bitmap->bitmap.width; x++)
           {
             if (((long) (point.x+x+0.5) < 0) || (*p == 0) ||
@@ -1335,7 +1328,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
             fill_color=GetFillColor(draw_info,(long) (point.x+x+0.5),(long)
               (point.y+y+0.5));
             fill_opacity=MaxRGB-fill_opacity*(MaxRGB-fill_color.opacity);
-            *q=MagickCompositeOver(&fill_color,fill_opacity,q,q->opacity);
+            MagickCompositeOver(&fill_color,fill_opacity,q,q->opacity,q);
             if (active == MagickFalse)
               (void) SyncImagePixels(image);
             p++;
@@ -1410,9 +1403,6 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
 %
 %  A description of each parameter follows:
 %
-%    o status: Method RenderPostscript returns MagickTrue if the text is rendered on
-%      the image, otherwise MagickFalse.
-%
 %    o image: The image.
 %
 %    o draw_info: The draw info.
@@ -1593,7 +1583,7 @@ static MagickBooleanType RenderPostscript(Image *image,
         resolution.y=resolution.x;
     }
   if (identity == MagickFalse)
-    TransformImage(&annotate_image,"0x0",(char *) NULL);
+    (void) TransformImage(&annotate_image,"0x0",(char *) NULL);
   else
     {
       RectangleInfo
@@ -1605,7 +1595,7 @@ static MagickBooleanType RenderPostscript(Image *image,
       crop_info.y=(long) ((resolution.y/72.0)*extent.y/8.0+0.5);
       (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu%+ld%+ld",
         crop_info.width,crop_info.height,crop_info.x,crop_info.y);
-      TransformImage(&annotate_image,geometry,(char *) NULL);
+      (void) TransformImage(&annotate_image,geometry,(char *) NULL);
     }
   metrics->pixels_per_em.x=(resolution.y/72.0)*
     ExpandAffine(&draw_info->affine)*draw_info->pointsize;
@@ -1693,9 +1683,6 @@ static MagickBooleanType RenderPostscript(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o status: Method RenderX11 returns MagickTrue if the text is rendered on the
-%      image, otherwise MagickFalse.
-%
 %    o image: The image.
 %
 %    o draw_info: The draw info.
