@@ -266,14 +266,11 @@ MagickExport void Ascii85Initialize(Image *image)
     Allocate image structure.
   */
   if (image->ascii85 == (Ascii85Info *) NULL)
-    image->ascii85=(Ascii85Info *) AcquireMagickMemory(sizeof(Ascii85Info));
-  else
-    image->ascii85=(Ascii85Info *)
-      ResizeMagickMemory(image->ascii85,sizeof(Ascii85Info));
+    image->ascii85=(Ascii85Info *) AcquireMagickMemory(sizeof(*image->ascii85));
   if (image->ascii85 == (Ascii85Info *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       image->filename);
-  (void) ResetMagickMemory(image->ascii85,0,sizeof(Ascii85Info));
+  (void) ResetMagickMemory(image->ascii85,0,sizeof(*image->ascii85));
   image->ascii85->line_break=MaxLineExtent << 1;
   image->ascii85->offset=0;
 }
@@ -415,6 +412,9 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
     count,
     y;
 
+  MagickBooleanType
+    status;
+
   register IndexPacket
     *indexes;
 
@@ -450,10 +450,8 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
-  mb_hash=(HuffmanTable **)
-    AcquireMagickMemory(HashSize*sizeof(HuffmanTable *));
-  mw_hash=(HuffmanTable **)
-    AcquireMagickMemory(HashSize*sizeof(HuffmanTable *));
+  mb_hash=(HuffmanTable **) AcquireMagickMemory(HashSize*sizeof(*mb_hash));
+  mw_hash=(HuffmanTable **) AcquireMagickMemory(HashSize*sizeof(*mw_hash));
   scanline=(unsigned char *) AcquireMagickMemory((size_t) image->columns);
   if ((mb_hash == (HuffmanTable **) NULL) ||
       (mw_hash == (HuffmanTable **) NULL) ||
@@ -612,9 +610,12 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if (QuantumTick(y,image->rows) != 0)
-      if (MagickMonitor(LoadImageTag,y,image->rows,&image->exception) == MagickFalse)
-        break;
+    if (QuantumTick(y,image->rows) != MagickFalse)
+      {
+        status=MagickMonitor(LoadImageTag,y,image->rows,&image->exception);
+        if (status == MagickFalse)
+          break;
+      }
     y++;
   }
   image->rows=(unsigned long) Max(y-3,1);
@@ -836,7 +837,7 @@ MagickExport MagickBooleanType HuffmanEncodeImage(const ImageInfo *image_info,
     OutputBit(1);
     q=scanline;
     if (huffman_image->previous == (Image *) NULL)
-      if (QuantumTick(y,huffman_image->rows) != 0)
+      if (QuantumTick(y,huffman_image->rows) != MagickFalse)
         {
           status=MagickMonitor(SaveImageTag,y,huffman_image->rows,
             &image->exception);
@@ -1169,7 +1170,7 @@ MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   assert(pixels != (unsigned char *) NULL);
-  table=(TableType *) AcquireMagickMemory((1 << 12)*sizeof(TableType));
+  table=(TableType *) AcquireMagickMemory((1 << 12)*sizeof(*table));
   if (table == (TableType *) NULL)
     return(MagickFalse);
   /*
