@@ -70,11 +70,11 @@ static const char
 static LinkedListInfo
   *configure_list = (LinkedListInfo *) NULL;
 
-static MagickBooleanType
-  instantiate_configure = MagickFalse;
-
 static SemaphoreInfo
   *configure_semaphore = (SemaphoreInfo *) NULL;
+
+static volatile MagickBooleanType
+  instantiate_configure = MagickFalse;
 
 /*
   Forward declarations.
@@ -204,6 +204,7 @@ MagickExport const ConfigureInfo *GetConfigureInfo(const char *name,
   register const ConfigureInfo
     *p;
 
+  assert(exception != (ExceptionInfo *) NULL);
   if ((configure_list == (LinkedListInfo *) NULL) ||
       (instantiate_configure == MagickFalse))
     (void) InitializeConfigureList(exception);
@@ -309,7 +310,7 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
   if (p == (const ConfigureInfo *) NULL)
     return((const ConfigureInfo **) NULL);
   options=(const ConfigureInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(ConfigureInfo *));
+    (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(*options));
   if (options == (const ConfigureInfo **) NULL)
     return((const ConfigureInfo **) NULL);
   /*
@@ -320,13 +321,13 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
   p=(const ConfigureInfo *) GetNextElementInLinkedList(configure_list);
   for (i=0; p != (const ConfigureInfo *) NULL; )
   {
-    if ((p->stealth == MagickFalse) && (GlobExpression(p->name,pattern) != MagickFalse))
+    if ((p->stealth == MagickFalse) &&
+        (GlobExpression(p->name,pattern) != MagickFalse))
       options[i++]=p;
     p=(const ConfigureInfo *) GetNextElementInLinkedList(configure_list);
   }
   RelinquishSemaphoreInfo(&configure_semaphore);
-  qsort((void *) options,(size_t) i,sizeof(ConfigureInfo **),
-    ConfigureInfoCompare);
+  qsort((void *) options,(size_t) i,sizeof(*options),ConfigureInfoCompare);
   options[i]=(ConfigureInfo *) NULL;
   *number_options=(unsigned long) i;
   return(options);
@@ -409,19 +410,20 @@ MagickExport char **GetConfigureList(const char *pattern,
   AcquireSemaphoreInfo(&configure_semaphore);
   RelinquishSemaphoreInfo(&configure_semaphore);
   options=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(char *));
+    (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(*options));
   if (options == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&configure_semaphore);
   p=(const ConfigureInfo *) GetNextElementInLinkedList(configure_list);
   for (i=0; p != (const ConfigureInfo *) NULL; )
   {
-    if ((p->stealth == MagickFalse) && (GlobExpression(p->name,pattern) != MagickFalse))
+    if ((p->stealth == MagickFalse) &&
+        (GlobExpression(p->name,pattern) != MagickFalse))
       options[i++]=AcquireString(p->name);
     p=(const ConfigureInfo *) GetNextElementInLinkedList(configure_list);
   }
   RelinquishSemaphoreInfo(&configure_semaphore);
-  qsort((void *) options,(size_t) i,sizeof(char **),ConfigureCompare);
+  qsort((void *) options,(size_t) i,sizeof(*options),ConfigureCompare);
   options[i]=(char *) NULL;
   *number_options=(unsigned long) i;
   return(options);
@@ -510,7 +512,7 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
   }
 #endif
   if (GetNumberOfElementsInLinkedList(options) == 0)
-    ThrowMagickException(exception,GetMagickModule(),ConfigureError,
+    (void) ThrowMagickException(exception,GetMagickModule(),ConfigureError,
       "UnableToOpenConfigureFile",filename);
   ResetLinkedListIterator(options);
   return(options);
@@ -656,7 +658,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
       /*
         Search based on executable directory if directory is known.
       */
-      (void) strncpy(prefix,GetClientPath(),MaxTextExtent-1);
+      (void) CopyMagickString(prefix,GetClientPath(),MaxTextExtent);
       ChopPathComponents(prefix,1);
       (void) FormatMagickString(path,MaxTextExtent,"%s/lib/%s/",prefix,
         MagickLibConfigSubDir);
@@ -761,7 +763,7 @@ static MagickBooleanType InitializeConfigureList(ExceptionInfo *exception)
       if (active == MagickTrue)
         (void) LoadConfigureLists(ConfigureFilename,exception);
     }
-  return(configure_list != (LinkedListInfo *) NULL);
+  return(configure_list != (LinkedListInfo *) NULL ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -883,7 +885,7 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
   ConfigureInfo
     *configure_info = (ConfigureInfo *) NULL;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   size_t
@@ -968,11 +970,11 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
           Allocate memory for the configure list.
         */
         configure_info=(ConfigureInfo *)
-          AcquireMagickMemory(sizeof(ConfigureInfo));
+          AcquireMagickMemory(sizeof(*configure_info));
         if (configure_info == (ConfigureInfo *) NULL)
           ThrowMagickFatalException(ResourceLimitFatalError,
             "MemoryAllocationFailed",filename);
-        (void) ResetMagickMemory(configure_info,0,sizeof(ConfigureInfo));
+        (void) ResetMagickMemory(configure_info,0,sizeof(*configure_info));
         configure_info->path=AcquireString(filename);
         configure_info->signature=MagickSignature;
         continue;
@@ -1021,7 +1023,7 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
   token=(char *) RelinquishMagickMemory(token);
   if (configure_list == (LinkedListInfo *) NULL)
     return(MagickFalse);
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -1060,7 +1062,7 @@ static MagickBooleanType LoadConfigureLists(const char *filename,
   LinkedListInfo
     *options;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   status=MagickFalse;
@@ -1073,7 +1075,8 @@ static MagickBooleanType LoadConfigureLists(const char *filename,
     option=(const StringInfo *) GetNextElementInLinkedList(options);
   }
   DestroyConfigureOptions(options);
-  if (status == MagickFalse)
-    status=LoadConfigureList(ConfigureMap,"built-in",0,exception);
-  return(status);
+  if ((configure_list == (LinkedListInfo *) NULL) || 
+      (IsLinkedListEmpty(configure_list) != MagickFalse))
+    status|=LoadConfigureList(ConfigureMap,"built-in",0,exception);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
