@@ -260,7 +260,7 @@ static void ConvertUsage(void)
       "-ordered-dither NxN",
       "                     ordered dither the image",
       "-orient type         image orientation",
-      "-page geometry       size and location of an image canvas",
+      "-page geometry       size and location of an image canvas (setting)",
       "-paint radius        simulate an oil painting",
       "-ping                efficiently determine image attributes",
       "-pointsize value     font point size",
@@ -276,8 +276,9 @@ static void ConvertUsage(void)
       "-raise value         lighten/darken image edges to create a 3-D effect",
       "-red-primary point   chromaticity red primary point",
       "-render              render vector graphics",
-      "-resize geometry     resize the image",
+      "-repage geometry     size and location of an image canvas (operator)",
       "-resample geometry   change the resolution of an image",
+      "-resize geometry     resize the image",
       "-roll geometry       roll an image vertically or horizontally",
       "-rotate degrees      apply Paeth rotation to the image",
       "-sample geometry     scale image with pixel sampling",
@@ -393,7 +394,9 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
 
   MagickBooleanType
     pend,
-    ping,
+    ping;
+
+  MagickStatusType
     status;
 
   register long
@@ -478,7 +481,7 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         AppendImageToList(&image_stack[k],next_image);
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL;
+    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -815,8 +818,8 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 i++;
                 if (i == (long) (argc-1))
                   ThrowConvertException(OptionError,"MissingArgument",option);
-                compression=ParseMagickOption(MagickCompressionOptions,MagickFalse,
-                  argv[i]);
+                compression=ParseMagickOption(MagickCompressionOptions,
+                  MagickFalse,argv[i]);
                 if (compression < 0)
                   ThrowConvertException(OptionError,
                     "UnrecognizedImageCompression",argv[i]);
@@ -1075,7 +1078,8 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 i++;
                 if (i == (long) (argc-1))
                   ThrowConvertException(OptionError,"MissingArgument",option);
-                endian=ParseMagickOption(MagickEndianOptions,MagickFalse,argv[i]);
+                endian=ParseMagickOption(MagickEndianOptions,MagickFalse,
+                  argv[i]);
                 if (endian < 0)
                   ThrowConvertException(OptionError,"UnrecognizedEndianType",
                     argv[i]);
@@ -1439,12 +1443,15 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 i++;
                 if (i == (long) argc)
                   ThrowConvertException(OptionError,"MissingArgument",option);
-                if (IsGeometry(argv[i]) == MagickFalse)
-                  ThrowConvertInvalidArgumentException(option,argv[i]);
                 limit=(~0UL);
                 if (LocaleCompare("unlimited",argv[i]) != 0)
-                  limit=(unsigned long) atol(argv[i]);
-                resource=ParseMagickOption(MagickResourceOptions,MagickFalse,type);
+                  {
+                    if (IsGeometry(argv[i]) == MagickFalse)
+                      ThrowConvertInvalidArgumentException(option,argv[i]);
+                    limit=(unsigned long) atol(argv[i]);
+                  }
+                resource=ParseMagickOption(MagickResourceOptions,MagickFalse,
+                  type);
                 if (resource < 0)
                   ThrowConvertException(OptionError,
                     "UnrecognizedResourceType",type);
@@ -1943,6 +1950,18 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("render",option+1) == 0)
           break;
+        if (LocaleCompare("repage",option+1) == 0)
+          {
+            if (*option == '-')
+              {
+                i++;
+                if (i == (long) (argc-1))
+                  ThrowConvertException(OptionError,"MissingArgument",option);
+                if (IsGeometry(argv[i]) == MagickFalse)
+                  ThrowConvertInvalidArgumentException(option,argv[i]);
+              }
+            break;
+          }
         if (LocaleCompare("resample",option+1) == 0)
           {
             if (*option == '-')
@@ -2056,7 +2075,7 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                   ThrowConvertInvalidArgumentException(option,argv[i]);
               }
             seed=(unsigned long) atol(argv[i]);
-            DistillRandomEvent((unsigned char *) &seed,sizeof(unsigned long));
+            DistillRandomEvent((unsigned char *) &seed,sizeof(seed));
             break;
           }
         if (LocaleCompare("segment",option+1) == 0)
@@ -2509,7 +2528,9 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       default:
         ThrowConvertException(OptionError,"UnrecognizedOption",option)
     }
-    if (ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) == MagickTrue)
+    status=(MagickStatusType)
+      ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1);
+    if (status == MagickTrue)
       MogrifyImageStack(image_stack[k],MagickTrue);
   }
   if (k != 0)
@@ -2533,5 +2554,5 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       text=(char *) RelinquishMagickMemory(text);
     }
   DestroyConvert();
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
