@@ -41,6 +41,8 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/color_private.h"
+#include "magick/colorspace_private.h"
 #include "magick/decorate.h"
 #include "magick/error.h"
 #include "magick/image.h"
@@ -153,22 +155,26 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   long
     y;
 
+  MagickPixelPacket
+    accentuate,
+    highlight,
+    matte,
+    shadow,
+    trough;
+
   register const PixelPacket
     *p;
 
+  register IndexPacket
+    *frame_indexes,
+    *indexes;
+
   register long
     x;
 
   register PixelPacket
     *q;
 
-  PixelPacket
-    accentuate,
-    highlight,
-    matte,
-    shadow,
-    trough;
-
   unsigned long
     bevel_width,
     height,
@@ -193,94 +199,150 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   frame_image=CloneImage(image,frame_info->width,frame_info->height,MagickTrue,
     exception);
   if (frame_image == (Image *) NULL)
-    return(MagickFalse);
+    return((Image *) NULL);
   frame_image->storage_class=DirectClass;
-  frame_image->matte|=(frame_image->matte_color.opacity != OpaqueOpacity);
+  if (frame_image->matte_color.opacity != OpaqueOpacity)
+    frame_image->matte=MagickTrue;
+  frame_image->page=image->page;
+  if ((image->page.width != 0) && (image->page.height != 0))
+    {
+      frame_image->page.width+=frame_image->columns-image->columns;
+      frame_image->page.height+=frame_image->rows-image->rows;
+    }
   /*
     Initialize 3D effects color.
   */
-  matte=image->matte_color;
-  accentuate.red=(Quantum) (QuantumScale*(((MagickRealType) MaxRGB-
-    AccentuateModulate)*matte.red+((MagickRealType) MaxRGB*
-    AccentuateModulate))+0.5);
-  accentuate.green=(Quantum) (QuantumScale*(((MagickRealType) MaxRGB-
-    AccentuateModulate)*matte.green+((MagickRealType) MaxRGB*
-    AccentuateModulate))+0.5);
-  accentuate.blue=(Quantum) (QuantumScale*(((MagickRealType) MaxRGB-
-    AccentuateModulate)*matte.blue+((MagickRealType) MaxRGB*
-    AccentuateModulate))+0.5);
+  GetMagickPixelPacket(image,&matte);
+  matte.colorspace=RGBColorspace;
+  SetMagickPixelPacket(&image->matte_color,(IndexPacket *) NULL,&matte);
+  GetMagickPixelPacket(image,&accentuate);
+  accentuate.red=QuantumScale*((MaxRGB-AccentuateModulate)*matte.red+
+    (MaxRGB*AccentuateModulate));
+  accentuate.green=QuantumScale*((MaxRGB-AccentuateModulate)*matte.green+
+    (MaxRGB*AccentuateModulate));
+  accentuate.blue=QuantumScale*((MaxRGB-AccentuateModulate)*matte.blue+
+    (MaxRGB*AccentuateModulate));
   accentuate.opacity=matte.opacity;
-  highlight.red=(Quantum) (QuantumScale*(((MagickRealType) MaxRGB-
-    HighlightModulate)*matte.red+((MagickRealType) MaxRGB*
-    HighlightModulate))+0.5);
-  highlight.green=(Quantum) (QuantumScale*(((MagickRealType) MaxRGB-
-    HighlightModulate)*matte.green+((MagickRealType) MaxRGB*
-    HighlightModulate))+0.5);
-  highlight.blue=(Quantum) (QuantumScale*(((MagickRealType) MaxRGB-
-    HighlightModulate)*matte.blue+((MagickRealType) MaxRGB*
-    HighlightModulate))+0.5);
+  GetMagickPixelPacket(image,&highlight);
+  highlight.red=QuantumScale*((MaxRGB-HighlightModulate)*matte.red+
+    (MaxRGB*HighlightModulate));
+  highlight.green=QuantumScale*((MaxRGB-HighlightModulate)*matte.green+
+    (MaxRGB*HighlightModulate));
+  highlight.blue=QuantumScale*((MaxRGB-HighlightModulate)*matte.blue+
+    (MaxRGB*HighlightModulate));
   highlight.opacity=matte.opacity;
-  shadow.red=(Quantum) (QuantumScale*((MagickRealType) matte.red*
-    ShadowModulate)+0.5);
-  shadow.green=(Quantum) (QuantumScale*((MagickRealType) matte.green*
-    ShadowModulate)+0.5);
-  shadow.blue=(Quantum) (QuantumScale*((MagickRealType) matte.blue*
-    ShadowModulate)+0.5);
+  GetMagickPixelPacket(image,&shadow);
+  shadow.red=QuantumScale*matte.red*ShadowModulate;
+  shadow.green=QuantumScale*matte.green*ShadowModulate;
+  shadow.blue=QuantumScale*matte.blue*ShadowModulate;
   shadow.opacity=matte.opacity;
-  trough.red=(Quantum) (QuantumScale*((MagickRealType) matte.red*
-    TroughModulate)+0.5);
-  trough.green=(Quantum) (QuantumScale*((MagickRealType) matte.green*
-    TroughModulate)+0.5);
-  trough.blue=(Quantum) (QuantumScale*((MagickRealType) matte.blue*
-    TroughModulate)+0.5);
+  GetMagickPixelPacket(image,&trough);
+  trough.red=QuantumScale*matte.red*TroughModulate;
+  trough.green=QuantumScale*matte.green*TroughModulate;
+  trough.blue=QuantumScale*matte.blue*TroughModulate;
   trough.opacity=matte.opacity;
+  if (image->colorspace == CMYKColorspace)
+    {
+      RGBtoCMYK(&matte);
+      RGBtoCMYK(&accentuate);
+      RGBtoCMYK(&highlight);
+      RGBtoCMYK(&shadow);
+      RGBtoCMYK(&trough);
+    }
   /*
     Draw top of ornamental border.
   */
   height=(unsigned long) (frame_info->outer_bevel+(frame_info->y-bevel_width)+
     frame_info->inner_bevel);
   q=SetImagePixels(frame_image,0,0,frame_image->columns,height);
+  if (q == (PixelPacket *) NULL)
+    return(frame_image);
+  frame_indexes=GetIndexes(frame_image);
   if (q != (PixelPacket *) NULL)
     {
       for (y=0; y < (long) frame_info->outer_bevel; y++)
       {
         for (x=0; x < (long) (frame_image->columns-y); x++)
+        {
           if (x < y)
-            *q++=highlight;
+            SetPixelPacket(&highlight,q,frame_indexes);
           else
-            *q++=accentuate;
+            SetPixelPacket(&accentuate,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         for ( ; x < (long) frame_image->columns; x++)
-          *q++=shadow;
+        {
+          SetPixelPacket(&shadow,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
       }
       for (y=0; y < (long) (frame_info->y-bevel_width); y++)
       {
         for (x=0; x < (long) frame_info->outer_bevel; x++)
-          *q++=highlight;
+        {
+          SetPixelPacket(&highlight,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         width=frame_image->columns-2*frame_info->outer_bevel;
         for (x=0; x < (long) width; x++)
-          *q++=matte;
+        {
+          SetPixelPacket(&matte,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         for (x=0; x < (long) frame_info->outer_bevel; x++)
-          *q++=shadow;
+        {
+          SetPixelPacket(&shadow,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
       }
       for (y=0; y < (long) frame_info->inner_bevel; y++)
       {
         for (x=0; x < (long) frame_info->outer_bevel; x++)
-          *q++=highlight;
+        {
+          SetPixelPacket(&highlight,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         for (x=0; x < (long) (frame_info->x-bevel_width); x++)
-          *q++=matte;
+        {
+          SetPixelPacket(&matte,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         width=image->columns+((unsigned long) frame_info->inner_bevel << 1)-y;
         for (x=0; x < (long) width; x++)
+        {
           if (x < y)
-            *q++=shadow;
+            SetPixelPacket(&shadow,q,frame_indexes);
           else
-            *q++=trough;
+            SetPixelPacket(&trough,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         for ( ; x < (long) (image->columns+2*frame_info->inner_bevel); x++)
-          *q++=highlight;
+        {
+          SetPixelPacket(&highlight,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         width=frame_info->width-frame_info->x-image->columns-bevel_width;
         for (x=0; x < (long) width; x++)
-          *q++=matte;
+        {
+          SetPixelPacket(&matte,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
         for (x=0; x < (long) frame_info->outer_bevel; x++)
-          *q++=shadow;
+        {
+          SetPixelPacket(&shadow,q,frame_indexes);
+          q++;
+          frame_indexes++;
+        }
       }
       (void) SyncImagePixels(frame_image);
     }
@@ -296,27 +358,57 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     q=SetImagePixels(frame_image,0,frame_info->y+y,frame_image->columns,1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
+    indexes=GetIndexes(image);
+    frame_indexes=GetIndexes(frame_image);
     for (x=0; x < (long) frame_info->outer_bevel; x++)
-      *q++=highlight;
+    {
+      SetPixelPacket(&highlight,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) (frame_info->x-bevel_width); x++)
-      *q++=matte;
+    {
+      SetPixelPacket(&matte,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) frame_info->inner_bevel; x++)
-      *q++=shadow;
+    {
+      SetPixelPacket(&shadow,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     /*
       Transfer scanline.
     */
-    (void) CopyMagickMemory(q,p,(size_t) image->columns*sizeof(PixelPacket));
+    (void) CopyMagickMemory(q,p,(size_t) image->columns*sizeof(*q));
     q+=image->columns;
+    if (image->colorspace == CMYKColorspace)
+      (void) CopyMagickMemory(frame_indexes,indexes,
+        (size_t) image->columns*sizeof(*frame_indexes));
+    frame_indexes+=image->columns;
     for (x=0; x < (long) frame_info->inner_bevel; x++)
-      *q++=highlight;
+    {
+      SetPixelPacket(&highlight,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     width=frame_info->width-frame_info->x-image->columns-bevel_width;
     for (x=0; x < (long) width; x++)
-      *q++=matte;
+    {
+      SetPixelPacket(&matte,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) frame_info->outer_bevel; x++)
-      *q++=shadow;
+    {
+      SetPixelPacket(&shadow,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     if (SyncImagePixels(frame_image) == MagickFalse)
       break;
-    if (QuantumTick(y,image->rows) != 0)
+    if (QuantumTick(y,image->rows) != MagickFalse)
       if (MagickMonitor(FrameImageTag,y,image->rows,exception) == MagickFalse)
         break;
   }
@@ -329,44 +421,89 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     frame_image->columns,height);
   if (q == (PixelPacket *) NULL)
     return(frame_image);
+  frame_indexes=GetIndexes(frame_image);
   for (y=frame_info->inner_bevel-1; y >= 0; y--)
   {
     for (x=0; x < (long) frame_info->outer_bevel; x++)
-      *q++=highlight;
+    {
+      SetPixelPacket(&highlight,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) (frame_info->x-bevel_width); x++)
-      *q++=matte;
+    {
+      SetPixelPacket(&matte,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < y; x++)
-      *q++=shadow;
+    {
+      SetPixelPacket(&shadow,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for ( ; x < (long) (image->columns+2*frame_info->inner_bevel); x++)
+    {
       if (x >= (long) (image->columns+2*frame_info->inner_bevel-y))
-        *q++=highlight;
+        SetPixelPacket(&highlight,q,frame_indexes);
       else
-        *q++=accentuate;
+        SetPixelPacket(&accentuate,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     width=frame_info->width-frame_info->x-image->columns-bevel_width;
     for (x=0; x < (long) width; x++)
-      *q++=matte;
+    {
+      SetPixelPacket(&matte,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) frame_info->outer_bevel; x++)
-      *q++=shadow;
+    {
+      SetPixelPacket(&shadow,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
   }
   height=frame_info->height-frame_info->y-image->rows-bevel_width;
   for (y=0; y < (long) height; y++)
   {
     for (x=0; x < (long) frame_info->outer_bevel; x++)
-      *q++=highlight;
+    {
+      SetPixelPacket(&highlight,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) (frame_image->columns-2*frame_info->outer_bevel); x++)
-      *q++=matte;
+    {
+      SetPixelPacket(&matte,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for (x=0; x < (long) frame_info->outer_bevel; x++)
-      *q++=shadow;
+    {
+      SetPixelPacket(&shadow,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
   }
   for (y=frame_info->outer_bevel-1; y >= 0; y--)
   {
     for (x=0; x < y; x++)
-      *q++=highlight;
+    {
+      SetPixelPacket(&highlight,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
     for ( ; x < (long) frame_image->columns; x++)
+    {
       if (x >= (long) (frame_image->columns-y))
-        *q++=shadow;
+        SetPixelPacket(&shadow,q,frame_indexes);
       else
-        *q++=trough;
+        SetPixelPacket(&trough,q,frame_indexes);
+      q++;
+      frame_indexes++;
+    }
   }
   (void) SyncImagePixels(frame_image);
   return(frame_image);
@@ -488,9 +625,12 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if (QuantumTick(y,image->rows) != 0)
-      if (MagickMonitor(RaiseImageTag,y,image->rows,&image->exception) == MagickFalse)
-        break;
+    if (QuantumTick(y,image->rows) != MagickFalse)
+      {
+        status=MagickMonitor(RaiseImageTag,y,image->rows,&image->exception);
+        if (status == MagickFalse)
+          break;
+      }
   }
   for ( ; y < (long) (image->rows-raise_info->height); y++)
   {
@@ -524,9 +664,12 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if (QuantumTick(y,image->rows) != 0)
-      if (MagickMonitor(RaiseImageTag,y,image->rows,&image->exception) == MagickFalse)
-        break;
+    if (QuantumTick(y,image->rows) != MagickFalse)
+      {
+        status=MagickMonitor(RaiseImageTag,y,image->rows,&image->exception);
+        if (status == MagickFalse)
+          break;
+      }
   }
   for ( ; y < (long) image->rows; y++)
   {
@@ -568,7 +711,7 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if (QuantumTick(y,image->rows) != 0)
+    if (QuantumTick(y,image->rows) != MagickFalse)
       {
         status=MagickMonitor(RaiseImageTag,y,image->rows,&image->exception);
         if (status == MagickFalse)
