@@ -187,7 +187,7 @@ MagickExport unsigned long GetOptimalKernelWidth1D(const double radius,
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"");
   assert(sigma != 0.0);
   if (radius > 0.0)
-    return((unsigned long) (2.0*ceil(radius)+1.0));
+    return(Max(2*((unsigned long) radius)+1,3));
   for (width=5; ;)
   {
     normalize=0.0;
@@ -220,7 +220,7 @@ MagickExport unsigned long GetOptimalKernelWidth2D(const double radius,
   assert(sigma != 0.0);
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"");
   if (radius > 0.0)
-    return((unsigned long) (2.0*ceil(radius)+1.0));
+    return(Max(2*((unsigned long) radius)+1,3));
   for (width=5; ;)
   {
     normalize=0.0;
@@ -298,13 +298,11 @@ MagickExport void HSBTransform(const double hue,const double saturation,
       *blue=(*red);
       return;
     }
-  h=6.0*hue;
-  if (h == 6.0)
-    h=0.0;
-  f=h-(int) h;
+  h=6.0*(hue-floor(hue));
+  f=h-floor(h);
   p=brightness*(1.0-saturation);
   q=brightness*(1.0-saturation*f);
-  t=brightness*(1.0-saturation*(1.0-f));
+  t=brightness*(1.0-(saturation*(1.0-f)));
   switch ((int) h)
   {
     case 0:
@@ -312,14 +310,14 @@ MagickExport void HSBTransform(const double hue,const double saturation,
     {
       *red=RoundToQuantum(MaxRGB*brightness);
       *green=RoundToQuantum(MaxRGB*t);
-      *blue= RoundToQuantum(MaxRGB*p);
+      *blue=RoundToQuantum(MaxRGB*p);
       break;
     }
     case 1:
     {
       *red=RoundToQuantum(MaxRGB*q);
       *green=RoundToQuantum(MaxRGB*brightness);
-      *blue= RoundToQuantum(MaxRGB*p);
+      *blue=RoundToQuantum(MaxRGB*p);
       break;
     }
     case 2:
@@ -681,8 +679,6 @@ MagickExport PixelPacket InterpolateColor(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   p=AcquireImagePixels(image,(long) x_offset,(long) y_offset,2,2,exception);
   if (p == (const PixelPacket *) NULL)
     return(AcquireOnePixel(image,(long) x_offset,(long) y_offset,exception));
@@ -749,10 +745,6 @@ MagickExport void Modulate(const double percent_hue,
   brightness*=0.01*percent_brightness;
   saturation*=0.01*percent_saturation;
   hue*=0.01*percent_hue;
-  while (hue < 0.0)
-    hue+=1.0;
-  while (hue > 1.0)
-    hue-=1.0;
   HSBTransform(hue,saturation,brightness,red,green,blue);
 }
 
@@ -805,13 +797,14 @@ MagickExport void TransformHSB(const Quantum red,const Quantum green,
   min=(MagickRealType) (red < green ? red : green);
   if ((MagickRealType) blue < min)
     min=(MagickRealType) blue;
-  *hue=0.0;
-  *saturation=0.0;
-  if (max != 0.0)
-    *saturation=(max-min)/max;
   *brightness=QuantumScale*max;
-  if (*saturation == 0.0)
-    return;
+  if (max == 0.0)
+    {
+      *saturation=0.0;
+      *hue=0.0;
+      return;
+    }
+  *saturation=1.0-min/max;
   delta=max-min;
   if ((MagickRealType) red == max)
     *hue=(green-(MagickRealType) blue)/delta;
@@ -819,14 +812,10 @@ MagickExport void TransformHSB(const Quantum red,const Quantum green,
     if ((MagickRealType) green == max)
       *hue=2.0+(blue-(MagickRealType) red)/delta;
     else
-      if ((MagickRealType) blue == max)
-        *hue=4.0+(red-(MagickRealType) green)/delta;
+      *hue=4.0+(red-(MagickRealType) green)/delta;
   *hue/=6.0;
   if (*hue < 0.0)
     *hue+=1.0;
-  else
-    if (*hue > 1.0)
-      *hue-=1.0;
 }
 
 /*
