@@ -254,7 +254,7 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   long
     snapshots;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   QuantizeInfo
@@ -284,7 +284,7 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   image=(Image *) NULL;
   option=(char *) NULL;
   resource_database=(XrmDatabase) NULL;
-  (void) ResetMagickMemory(&resource_info,0,sizeof(XResourceInfo));
+  (void) ResetMagickMemory(&resource_info,0,sizeof(resource_info));
   server_name=(char *) NULL;
   SetNotifyHandlers;
   /*
@@ -847,11 +847,13 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
                 i++;
                 if (i == (long) argc)
                   ThrowImportException(OptionError,"MissingArgument",option);
-                if (IsGeometry(argv[i]) == MagickFalse)
-                  ThrowImportInvalidArgumentException(option,argv[i]);
                 limit=(~0UL);
                 if (LocaleCompare("unlimited",argv[i]) != 0)
-                  limit=(unsigned long) atol(argv[i]);
+                  {
+                    if (IsGeometry(argv[i]) == MagickFalse)
+                      ThrowImportInvalidArgumentException(option,argv[i]);
+                    limit=(unsigned long) atol(argv[i]);
+                  }
                 resource=ParseMagickOption(MagickResourceOptions,MagickFalse,
                   type);
                 if (resource < 0)
@@ -1180,9 +1182,9 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
     image=image->previous;
   status&=MogrifyImages(image_info,argc-1,argv,&image);
   GetImageException(image,exception);
-  status&=WriteImages(image_info,image,filename,&image->exception);
+  status&=WriteImages(image_info,image,filename,exception);
   DestroyImport();
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 #else
   (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
     "XWindowLibraryIsNotAvailable",image_info->filename);
