@@ -553,8 +553,8 @@ MagickExport Image **ImageListToArray(const Image *images,
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
-  group=(Image **) AcquireMagickMemory(
-    (size_t) (GetImageListLength(images)+1)*sizeof(Image *));
+  group=(Image **) AcquireMagickMemory((size_t)
+    (GetImageListLength(images)+1)*sizeof(*group));
   if (group == (Image **) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
@@ -1076,5 +1076,6 @@ MagickExport Image *SyncNextImageInList(const Image *images)
       DestroyBlob(images->next);
       images->next->blob=ReferenceBlob(images->blob);
     }
+  images->next->endian=images->endian;
   return(images->next);
 }
