@@ -112,11 +112,11 @@ static const char
 static LinkedListInfo
   *log_list = (LinkedListInfo *) NULL;
 
-static MagickBooleanType
-  instantiate_log = MagickFalse;
-
 static SemaphoreInfo
   *log_semaphore = (SemaphoreInfo *) NULL;
+
+static volatile MagickBooleanType
+  instantiate_log = MagickFalse;
 
 /*
   Forward declarations.
@@ -213,6 +213,7 @@ MagickExport const LogInfo *GetLogInfo(const char *name,
   register const LogInfo
     *p;
 
+  assert(exception != (ExceptionInfo *) NULL);
   if ((log_list == (LinkedListInfo *) NULL) || (instantiate_log == MagickFalse))
     if (InitializeLogList(exception) == MagickFalse)
       return((const LogInfo *) NULL);
@@ -315,7 +316,7 @@ MagickExport const LogInfo **GetLogInfoList(const char *pattern,
   if (p == (const LogInfo *) NULL)
     return((const LogInfo **) NULL);
   preferences=(const LogInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(log_list)+1)*sizeof(LogInfo *));
+    (GetNumberOfElementsInLinkedList(log_list)+1)*sizeof(*preferences));
   if (preferences == (const LogInfo **) NULL)
     return((const LogInfo **) NULL);
   /*
@@ -326,12 +327,13 @@ MagickExport const LogInfo **GetLogInfoList(const char *pattern,
   p=(const LogInfo *) GetNextElementInLinkedList(log_list);
   for (i=0; p != (const LogInfo *) NULL; )
   {
-    if ((p->stealth == MagickFalse) && (GlobExpression(p->name,pattern) != MagickFalse))
+    if ((p->stealth == MagickFalse) &&
+        (GlobExpression(p->name,pattern) != MagickFalse))
       preferences[i++]=p;
     p=(const LogInfo *) GetNextElementInLinkedList(log_list);
   }
   RelinquishSemaphoreInfo(&log_semaphore);
-  qsort((void *) preferences,(size_t) i,sizeof(LogInfo **),LogInfoCompare);
+  qsort((void *) preferences,(size_t) i,sizeof(*preferences),LogInfoCompare);
   preferences[i]=(LogInfo *) NULL;
   *number_preferences=(unsigned long) i;
   return(preferences);
@@ -410,7 +412,7 @@ MagickExport char **GetLogList(const char *pattern,
   if (p == (const LogInfo *) NULL)
     return((char **) NULL);
   preferences=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(log_list)+1)*sizeof(char *));
+    (GetNumberOfElementsInLinkedList(log_list)+1)*sizeof(*preferences));
   if (preferences == (char **) NULL)
     return((char **) NULL);
   /*
@@ -421,12 +423,13 @@ MagickExport char **GetLogList(const char *pattern,
   p=(const LogInfo *) GetNextElementInLinkedList(log_list);
   for (i=0; p != (const LogInfo *) NULL; )
   {
-    if ((p->stealth == MagickFalse) && (GlobExpression(p->name,pattern) != MagickFalse))
+    if ((p->stealth == MagickFalse) &&
+        (GlobExpression(p->name,pattern) != MagickFalse))
       preferences[i++]=AcquireString(p->name);
     p=(const LogInfo *) GetNextElementInLinkedList(log_list);
   }
   RelinquishSemaphoreInfo(&log_semaphore);
-  qsort((void *) preferences,(size_t) i,sizeof(char **),LogCompare);
+  qsort((void *) preferences,(size_t) i,sizeof(*preferences),LogCompare);
   preferences[i]=(char *) NULL;
   *number_preferences=(unsigned long) i;
   return(preferences);
@@ -473,7 +476,7 @@ static MagickBooleanType InitializeLogList(ExceptionInfo *exception)
       if (active == MagickTrue)
         (void) LoadLogLists(LogFilename,exception);
     }
-  return(log_list != (LinkedListInfo *) NULL);
+  return(log_list != (LinkedListInfo *) NULL ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -488,7 +491,7 @@ static MagickBooleanType InitializeLogList(ExceptionInfo *exception)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  IsEventLogging() returns MagickTrue if debug of events is enabled otherwise
-%  False.
+%  MagickFalse.
 %
 %  The format of the IsEventLogging method is:
 %
@@ -604,7 +607,7 @@ MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  LogMagickEvent() logs an event as determined by the log configuration file.
-%  If an error occurs, False is returned otherwise True.
+%  If an error occurs, MagickFalse is returned otherwise MagickTrue.
 %
 %  The format of the LogMagickEvent method is:
 %
@@ -711,7 +714,8 @@ static char *TranslateEvent(const LogEventType type,const char *module,
     if ((size_t) (q-text+MaxTextExtent) >= length)
       {
         length<<=1;
-        text=(char *) ResizeMagickMemory(text,length);
+        text=(char *) ResizeMagickMemory(text,
+          (length+MaxTextExtent)*sizeof(*text));
         if (text == (char *) NULL)
           return((char *) NULL);
         q=text+strlen(text);
@@ -996,7 +1000,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
   LogInfo
     *log_info = (LogInfo *) NULL;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   /*
@@ -1075,11 +1079,11 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
         /*
           Allocate memory for the log list.
         */
-        log_info=(LogInfo *) AcquireMagickMemory(sizeof(LogInfo));
+        log_info=(LogInfo *) AcquireMagickMemory(sizeof(*log_info));
         if (log_info == (LogInfo *) NULL)
           ThrowMagickFatalException(ResourceLimitFatalError,
             "MemoryAllocationFailed",filename);
-        (void) ResetMagickMemory(log_info,0,sizeof(LogInfo));
+        (void) ResetMagickMemory(log_info,0,sizeof(*log_info));
         log_info->path=AcquireString(filename);
         GetTimerInfo((TimerInfo *) &log_info->timer);
         log_info->signature=MagickSignature;
@@ -1172,7 +1176,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
   token=(char *) RelinquishMagickMemory(token);
   if (log_list == (LinkedListInfo *) NULL)
     return(MagickFalse);
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -1211,7 +1215,7 @@ static MagickBooleanType LoadLogLists(const char *filename,
   LinkedListInfo
     *options;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   status=MagickFalse;
@@ -1223,9 +1227,10 @@ static MagickBooleanType LoadLogLists(const char *filename,
     option=(const StringInfo *) GetNextElementInLinkedList(options);
   }
   DestroyConfigureOptions(options);
-  if (status == MagickFalse)
-    status=LoadLogList(LogMap,"built-in",0,exception);
-  return(status);
+  if ((log_list == (LinkedListInfo *) NULL) || 
+      (IsLinkedListEmpty(log_list) != MagickFalse))
+    status|=LoadLogList(LogMap,"built-in",0,exception);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
 
 /*
