@@ -44,8 +44,9 @@ typedef struct _MagickInfo
   MagickBooleanType
     adjoin,
     raw,
-    seekable_stream,
+    endian_support,
     blob_support,
+    seekable_stream,
     thread_support,
     stealth;
 
@@ -74,6 +75,7 @@ extern MagickExport EncoderHandler
 extern MagickExport MagickBooleanType
   GetMagickAdjoin(const MagickInfo *),
   GetMagickBlobSupport(const MagickInfo *),
+  GetMagickEndianSupport(const MagickInfo *),
   GetMagickSeekableStream(const MagickInfo *),
   GetMagickThreadSupport(const MagickInfo *),
   IsMagickInstantiated(void),
