@@ -90,7 +90,7 @@ static SemaphoreInfo
 
 static ResourceInfo
   resource_info =
-    { 0, 0, 0, 0, 0, 128, 512, 1024, ResourceInfinity, 768 };
+    { 0, 0, 0, 0, 0, 256, 512, 1024, ResourceInfinity, 768 };
 
 static LinkedListInfo
   *temporary_resources = (LinkedListInfo *) NULL;
@@ -106,8 +106,9 @@ static LinkedListInfo
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  AcquireMagickResource() acquires resources of the specified type.  True is
-%  returned if the specified resource is available otherwise MagickFalse.
+%  AcquireMagickResource() acquires resources of the specified type.
+%  MagickTrue is returned if the specified resource is available otherwise
+%  MagickFalse.
 %
 %  The format of the AcquireMagickResource() method is:
 %
@@ -146,7 +147,8 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
     {
       resource_info.area+=size;
       limit=MegabytesToBytes(resource_info.area_limit);
-      status=(resource_info.area_limit == ResourceInfinity) || (size < limit);
+      status=(resource_info.area_limit == ResourceInfinity) || (size < limit) ?
+        MagickTrue : MagickFalse;
       (void) FormatMagickString(resource_type,MaxTextExtent,"area");
       FormatSize((MagickSizeType) resource_info.area,resource_current);
       FormatSize(MegabytesToBytes(resource_info.area_limit),resource_limit);
@@ -157,7 +159,8 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       resource_info.memory+=size;
       limit=MegabytesToBytes(resource_info.memory_limit);
       status=(resource_info.memory_limit == ResourceInfinity) ||
-        ((MagickSizeType) (resource_info.memory+size) < limit);
+        ((MagickSizeType) (resource_info.memory+size) < limit) ?
+        MagickTrue : MagickFalse;
       (void) FormatMagickString(resource_type,MaxTextExtent,"memory");
       FormatSize((MagickSizeType) resource_info.memory,resource_current);
       FormatSize(MegabytesToBytes(resource_info.memory_limit),resource_limit);
@@ -168,7 +171,8 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       resource_info.map+=size;
       limit=MegabytesToBytes(resource_info.map_limit);
       status=(resource_info.map_limit == ResourceInfinity) ||
-        ((MagickSizeType) (resource_info.map+size) < limit);
+        ((MagickSizeType) (resource_info.map+size) < limit) ?
+        MagickTrue : MagickFalse;
       (void) FormatMagickString(resource_type,MaxTextExtent,"map");
       FormatSize((MagickSizeType) resource_info.map,resource_current);
       FormatSize(MegabytesToBytes(resource_info.map_limit),resource_limit);
@@ -179,7 +183,8 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       resource_info.disk+=size;
       limit=GigabytesToBytes(resource_info.disk_limit);
       status=(resource_info.disk_limit == ResourceInfinity) ||
-        ((MagickSizeType) (resource_info.disk+size) < limit);
+        ((MagickSizeType) (resource_info.disk+size) < limit) ?
+        MagickTrue : MagickFalse;
       (void) FormatMagickString(resource_type,MaxTextExtent,"disk");
       FormatSize((MagickSizeType) resource_info.disk,resource_current);
       FormatSize(GigabytesToBytes(resource_info.disk_limit),resource_limit);
@@ -190,7 +195,8 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       resource_info.file+=size;
       limit=resource_info.file_limit;
       status=(resource_info.file_limit == ResourceInfinity) ||
-        ((MagickSizeType) (resource_info.file+size) < limit);
+        ((MagickSizeType) (resource_info.file+size) < limit) ?
+        MagickTrue : MagickFalse;
       (void) FormatMagickString(resource_type,MaxTextExtent,"file");
       FormatSize((MagickSizeType) resource_info.file,resource_current);
       FormatSize((MagickSizeType) resource_info.file_limit,resource_limit);
@@ -210,6 +216,47 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   A s y n c h r o n o u s D e s t r o y M a g i c k R e s o u r c e s       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AsynchronousDestroyMagickResources() destroys the resource environment.
+%  It differs from DestroyMagickResources() in that it can be called from a
+%  asynchronous signal handler.
+%
+%  The format of the DestroyMagickResources() method is:
+%
+%      DestroyMagickResources(void)
+%
+%
+*/
+MagickExport void AsynchronousDestroyMagickResources(void)
+{
+  if (temporary_resources != (LinkedListInfo *) NULL)
+    {
+      const char
+        *path;
+
+      /*
+        Remove any lingering temporary files.
+      */
+      ResetLinkedListIterator(temporary_resources);
+      path=(const char *) GetNextElementInLinkedList(temporary_resources);
+      while (path != (const char *) NULL)
+      {
+        (void) remove(path);
+        path=(const char *) GetNextElementInLinkedList(temporary_resources);
+      }
+    }
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   A c q u i r e U n i q u e F i l e R e s o u r c e                         %
 %                                                                             %
 %                                                                             %
@@ -243,7 +290,7 @@ static MagickBooleanType GetPathTemplate(char *path)
     file_info;
 
   (void) strcpy(path,"magick-XXXXXXXX");
-   directory=getenv("TMPDIR");
+  directory=getenv("TMPDIR");
 #if defined(__WINDOWS__)
   if (directory == (char *) NULL)
     directory=getenv("TMP");
@@ -495,7 +542,7 @@ MagickExport void InitializeMagickResources(void)
 #if defined(PixelCacheThreshold)
   memory=PixelCacheThreshold;
 #endif
-  (void) SetMagickResourceLimit(AreaResource,memory/sizeof(PixelPacket));
+  (void) SetMagickResourceLimit(AreaResource,memory/2);
   (void) SetMagickResourceLimit(MemoryResource,memory);
   (void) SetMagickResourceLimit(MapResource,2*memory);
   p=getenv("MAGICK_AREA_LIMIT");
@@ -513,6 +560,8 @@ MagickExport void InitializeMagickResources(void)
   files=(-1);
 #if defined(HAVE_SYSCONF) && defined(_SC_OPEN_MAX)
   files=sysconf(_SC_OPEN_MAX);
+#elif defined(HAVE_GETDTABLESIZE) && defined(POSIX)
+  files=getdtablesize();
 #endif
   if (files <= 0)
     files=64;
