@@ -80,7 +80,7 @@ static LinkedListInfo
 static SemaphoreInfo
   *type_semaphore = (SemaphoreInfo *) NULL;
 
-static MagickBooleanType
+static volatile MagickBooleanType
   instantiate_type = MagickFalse;
 
 /*
@@ -181,6 +181,7 @@ MagickExport const TypeInfo *GetTypeInfo(const char *name,
   register const TypeInfo
     *p;
 
+  assert(exception != (ExceptionInfo *) NULL);
   if ((type_list == (LinkedListInfo *) NULL) ||
       (instantiate_type == MagickFalse))
     if (InitializeTypeList(exception) == MagickFalse)
@@ -389,7 +390,6 @@ MagickExport const TypeInfo *GetTypeInfoByFamily(const char *family,
       {
         max_score=score;
         type_info=p;
-        break;
       }
     p=(const TypeInfo *) GetNextElementInLinkedList(type_list);
   }
@@ -502,7 +502,7 @@ MagickExport const TypeInfo **GetTypeInfoList(const char *pattern,
   if (p == (const TypeInfo *) NULL)
     return((const TypeInfo **) NULL);
   fonts=(const TypeInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(type_list)+1)*sizeof(TypeInfo *));
+    (GetNumberOfElementsInLinkedList(type_list)+1)*sizeof(*fonts));
   if (fonts == (const TypeInfo **) NULL)
     return((const TypeInfo **) NULL);
   /*
@@ -513,12 +513,13 @@ MagickExport const TypeInfo **GetTypeInfoList(const char *pattern,
   p=(const TypeInfo *) GetNextElementInLinkedList(type_list);
   for (i=0; p != (const TypeInfo *) NULL; )
   {
-    if ((p->stealth == MagickFalse) && (GlobExpression(p->name,pattern) != MagickFalse))
+    if ((p->stealth == MagickFalse) &&
+        (GlobExpression(p->name,pattern) != MagickFalse))
       fonts[i++]=p;
     p=(const TypeInfo *) GetNextElementInLinkedList(type_list);
   }
   RelinquishSemaphoreInfo(&type_semaphore);
-  qsort((void *) fonts,(size_t) i,sizeof(TypeInfo **),TypeInfoCompare);
+  qsort((void *) fonts,(size_t) i,sizeof(*fonts),TypeInfoCompare);
   fonts[i]=(TypeInfo *) NULL;
   *number_fonts=(unsigned long) i;
   return(fonts);
@@ -596,7 +597,7 @@ MagickExport char **GetTypeList(const char *pattern,unsigned long *number_fonts)
   if (p == (const TypeInfo *) NULL)
     return((char **) NULL);
   fonts=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(type_list)+1)*sizeof(char *));
+    (GetNumberOfElementsInLinkedList(type_list)+1)*sizeof(*fonts));
   if (fonts == (char **) NULL)
     return((char **) NULL);
   /*
@@ -607,12 +608,13 @@ MagickExport char **GetTypeList(const char *pattern,unsigned long *number_fonts)
   p=(const TypeInfo *) GetNextElementInLinkedList(type_list);
   for (i=0; p != (const TypeInfo *) NULL; )
   {
-    if ((p->stealth == MagickFalse) && (GlobExpression(p->name,pattern) != MagickFalse))
+    if ((p->stealth == MagickFalse) &&
+        (GlobExpression(p->name,pattern) != MagickFalse))
       fonts[i++]=AcquireString(p->name);
     p=(const TypeInfo *) GetNextElementInLinkedList(type_list);
   }
   RelinquishSemaphoreInfo(&type_semaphore);
-  qsort((void *) fonts,(size_t) i,sizeof(char **),TypeCompare);
+  qsort((void *) fonts,(size_t) i,sizeof(*fonts),TypeCompare);
   fonts[i]=(char *) NULL;
   *number_fonts=(unsigned long) i;
   return(fonts);
@@ -796,7 +798,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
     *q,
     *token;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   TypeInfo
@@ -889,11 +891,11 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
         /*
           Allocate memory for the type list.
         */
-        type_info=(TypeInfo *) AcquireMagickMemory(sizeof(TypeInfo));
+        type_info=(TypeInfo *) AcquireMagickMemory(sizeof(*type_info));
         if (type_info == (TypeInfo *) NULL)
           ThrowMagickFatalException(ResourceLimitFatalError,
             "MemoryAllocationFailed",filename);
-        (void) ResetMagickMemory(type_info,0,sizeof(TypeInfo));
+        (void) ResetMagickMemory(type_info,0,sizeof(*type_info));
         type_info->path=AcquireString(filename);
         type_info->signature=MagickSignature;
         continue;
@@ -1045,7 +1047,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
   token=(char *) RelinquishMagickMemory(token);
   if (type_list == (LinkedListInfo *) NULL)
     return(MagickFalse);
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -1087,7 +1089,7 @@ static MagickBooleanType LoadTypeLists(const char *filename,
   LinkedListInfo
     *options;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   status=MagickFalse;
@@ -1126,7 +1128,8 @@ static MagickBooleanType LoadTypeLists(const char *filename,
             }
         }
     }
-  if (status == MagickFalse)
-    status=LoadTypeList(TypeMap,"built-in",0,exception);
-  return(status);
+  if ((type_list == (LinkedListInfo *) NULL) || 
+      (IsLinkedListEmpty(type_list) != MagickFalse))
+    status|=LoadTypeList(TypeMap,"built-in",0,exception);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
