@@ -147,11 +147,11 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
   image=GetImageFromMagickWand(wand);
   if (image == (Image *) NULL)
     return((PixelIterator *) NULL);
-  iterator=(PixelIterator *) AcquireMagickMemory(sizeof(PixelIterator));
+  iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*iterator));
   if (iterator == (PixelIterator *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       strerror(errno));
-  (void) ResetMagickMemory(iterator,0,sizeof(PixelIterator));
+  (void) ResetMagickMemory(iterator,0,sizeof(*iterator));
   GetExceptionInfo(&iterator->exception);
   iterator->view=OpenCacheView(image);
   SetGeometry(image,&iterator->region);
@@ -201,11 +201,11 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
   image=GetImageFromMagickWand(wand);
   if (image == (Image *) NULL)
     return((PixelIterator *) NULL);
-  iterator=(PixelIterator *) AcquireMagickMemory(sizeof(PixelIterator));
+  iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*iterator));
   if (iterator == (PixelIterator *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       strerror(errno));
-  (void) ResetMagickMemory(iterator,0,sizeof(PixelIterator));
+  (void) ResetMagickMemory(iterator,0,sizeof(*iterator));
   GetExceptionInfo(&iterator->exception);
   iterator->view=OpenCacheView(image);
   SetGeometry(image,&iterator->region);
